==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTSALESPRICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERCONTRACTSALESPRICEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTSALESPRICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTSALESPRICECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTSALESPRICEID_Type", propOrder = {
    "customercontractsalespricecode"
})
public class CUSTOMERCONTRACTSALESPRICEID_Type {

    @XmlElement(name = "CUSTOMERCONTRACTSALESPRICECODE", required = true)
    protected String customercontractsalespricecode;

    /**
     * Obtient la valeur de la propriété customercontractsalespricecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERCONTRACTSALESPRICECODE() {
        return customercontractsalespricecode;
    }

    /**
     * Définit la valeur de la propriété customercontractsalespricecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERCONTRACTSALESPRICECODE(String value) {
        this.customercontractsalespricecode = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTSALESPRICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERCONTRACTSALESPRICEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTSALESPRICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTSALESPRICECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTSALESPRICEID_Type", propOrder = {
    "customercontractsalespricecode"
})
public class CUSTOMERCONTRACTSALESPRICEID_Type {

    @XmlElement(name = "CUSTOMERCONTRACTSALESPRICECODE", required = true)
    protected String customercontractsalespricecode;

    /**
     * Gets the value of the customercontractsalespricecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERCONTRACTSALESPRICECODE() {
        return customercontractsalespricecode;
    }

    /**
     * Sets the value of the customercontractsalespricecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERCONTRACTSALESPRICECODE(String value) {
        this.customercontractsalespricecode = value;
    }

}
